@@ -7,6 +7,7 @@ from schema import Schema, Or, Optional, SchemaError
 cmd_schema_send = Schema({'type':
                           Or('set', 'get', 'describe', 'reset', 'stop'),
                           Optional('read_back', default=False): bool,
+                          Optional('from_hardware', default=False): bool,
                           'status': 'send',
                           'args': dict})
 
@@ -103,6 +104,33 @@ class Client():
 
         return roc_data
 
+    def get_from_hardware(self, config: dict = None) -> dict:
+        """
+        Takes any configuration dictionary and requests the ROC configuration
+        parameters specified directly from the registers. Behaves like
+        self.get(), except skips the cache and reads from hardware
+
+        :param config: Configuration dictionary with parameters to get
+        :type config: dict, optional
+        :return: Dictionary containing ROC register values as read from cache
+        :rtype: dict
+        :raises ValueError: Raises from _execute_transaction if server
+            responds with an error
+        """
+        if config is None:
+            if self.description is None:
+                self.description = \
+                        self._execute_transaction({'type': 'describe',
+                                                   'status': 'send',
+                                                   'args': {}})
+            board_type = list(self.description.keys())[0]
+            config = self.description[board_type]
+        null_config = self.set_values_for_read(config)
+        message = self._serialize('get', null_config, False, True)
+        roc_data = self._execute_transaction(message)
+
+        return roc_data
+
     def describe(self):
         """
         Returns a description of the board with parameter min and max values
@@ -166,7 +194,8 @@ class Client():
 
     def _serialize(self, type: str,
                    config: dict,
-                   readback: bool) -> dict:
+                   readback: bool,
+                   from_hardware: bool = False) -> dict:
         """
         Create a properly formatted dictionary from arguments.
 
@@ -179,12 +208,16 @@ class Client():
         readback: Enables readback after writing a configuration to a ROC. Only
             used with messages of type 'set', otherwise ignored
         :type readback: bool, optional
+        :param from_hardware: Requests that values be read directly from
+            hardware instead of cache. Only used for type 'get'
+        :type from_hardware: bool, optional
         :return: Message ready to send to server
         :rtype: dict
         """
         formatted_dict = {'type': type,
                           'status': 'send',
                           'read_back': readback,
+                          'from_hardware': from_hardware,
                           'args': config}
         try:
             formatted_dict = cmd_schema_send.validate(formatted_dict)
